@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-default-font-presets
-;; Package-Version: 20250921.944
-;; Package-Revision: 02175c87d908
+;; Package-Version: 20251126.350
+;; Package-Revision: 0ac18ca47b80
 ;; Package-Requires: ((emacs "26.1"))
 
 ;;; Commentary:
@@ -323,13 +323,13 @@ Return non-nil when the scale changed."
         (inhibit-redisplay t))
     (cond
      ((> target-width win-width)
-      (while (and (>= target-width win-width) (not (eq font-curr font-prev)))
+      (while (and (>= target-width win-width) (null (eq font-curr font-prev)))
         (decf default-font-presets--scale-delta)
         (setq font-prev font-curr)
         (setq font-curr (default-font-presets--index-update))
         (setq win-width (window-max-chars-per-line win))))
      ((< target-width win-width)
-      (while (and (< target-width win-width) (not (eq font-curr font-prev)))
+      (while (and (< target-width win-width) (null (eq font-curr font-prev)))
         (setq scale-delta-prev default-font-presets--scale-delta)
         (incf default-font-presets--scale-delta)
         (setq font-prev font-curr)
@@ -351,7 +351,7 @@ Return non-nil when the scale changed."
           (set-window-hscroll win hscroll-next))))
 
     ;; Return t when the scale changed.
-    (not (eq scale-delta-init default-font-presets--scale-delta))))
+    (null (eq scale-delta-init default-font-presets--scale-delta))))
 
 ;; ---------------------------------------------------------------------------
 ;; Public Functions
@@ -387,7 +387,7 @@ When nil, 1 is used."
      ((null current-font)
       (default-font-presets--message
        "warning, none of the %d font presets could be found!" list-len))
-     ((not (zerop skip-len))
+     ((null (zerop skip-len))
       (default-font-presets--message "%s, skipped %d" current-font skip-len))
      (t
       (default-font-presets--message "%s" current-font)))))
